@@ -1,4 +1,7 @@
 from .activity import Activity
+from .account_fixed_cost import AccountFixedCost
+from .account_hourly_rate import AccountHourlyRate
+from .account_internal_hourly_rate import AccountInternalHourlyRate
 
 from .project import Project
 from .project_recurring_expense import ProjectRecurringExpense
@@ -8,7 +11,7 @@ from .project_contract import ProjectContract
 from .project_task import ProjectTask
 from .project_report import ProjectReport
 
-from .user import User
+from .user import User, UserPerformanceReport
 from .user_presence import UserPresence
 from .user_employment import UserEmployment
 from .user_holiday import UserHoliday
@@ -23,11 +26,11 @@ from .deal_category import DealCategory
 from .company import Company
 from .comment import Comment
 from .schedule import Schedule
-from .session import Session
+from .session import SessionAuthentication, SessionVerification
 
 from .purchase_category import PurchaseCategory
 from .purchase import Purchase
 
 from .planning_entry import PlanningEntry
 
-from .hourly_rate import HourlyRate
+
