@@ -77,9 +77,47 @@ class TestProjectPaymentSchedule(UnitTest):
 
     def test_getlist(self):
         project_id = 1
+        from_date = "2021-02-03"
+        to_date = "2022-03-22"
+        checked = False
 
         response = self.moco.ProjectPaymentSchedule.getlist(
             project_id=project_id,
+            from_date=from_date,
+            to_date=to_date,
+            checked=checked
         )
 
+        params = response["params"]
+
         assert response["method"] == "GET"
+
+        assert params["from"] == from_date
+        assert params["to"] == to_date
+        assert params["checked"] == checked
+
+
+    def test_getall(self):
+        project_id = 2
+        company_id = 44
+        from_date = "2021-01-01"
+        to_date = "2023-03-24"
+        checked = True
+
+        response = self.moco.ProjectPaymentSchedule.getall(
+            from_date=from_date,
+            to_date=to_date,
+            checked=checked,
+            company_id=company_id,
+            project_id=project_id
+        )
+
+        params = response["params"]
+
+        assert response["method"] == "GET"
+
+        assert params["from"] == from_date
+        assert params["to"] == to_date
+        assert params["checked"] == checked
+        assert params["company_id"] == company_id
+        assert params["project_id"] == project_id
